@@ -1,8 +1,10 @@
 from albumentations.augmentations.transforms import VerticalFlip, \
-    HorizontalFlip, Flip, Normalize, ToFloat, RandomRotate90
+    HorizontalFlip, Flip, ToFloat
+from albumentations.augmentations.geometric import Rotate, RandomRotate90
 from albumentations.core.composition import Compose, OneOf, OneOrOther
 
-from .rotate_extended import Rotate
+from .normalize_extended import Normalize
+
 import logging
 
 __all__ = ['Rotate', 'build_pipeline', 'VerticalFlip',
@@ -11,13 +13,15 @@ __all__ = ['Rotate', 'build_pipeline', 'VerticalFlip',
            'OneOrOther', 'Compose']
 
 
-def build_pipeline(args):
+def build_pipeline(dstype, train_aug_dict, val_aug_dict):
     """Create train and val augmentation pipelines from args.
 
     Parameters
     ----------
-    args : dict
-        Arguments dictionary.
+    train_aug_dict : dict
+        Dictionary of augmentations to be done in training pipeline.
+    val_aug_dict : dict
+        Dictionary of augmentations to be done in validation pipeline.
 
     Returns
     -------
@@ -25,13 +29,14 @@ def build_pipeline(args):
         (train pipeline,val pipeline)
     """
     logging.debug("Enter build_pipeline routine")
-    train_aug_dict = args.train_augs
-    val_aug_dict = args.val_augs
-    train_aug_pipeline = process_aug_dict(train_aug_dict)
-    val_aug_pipeline = process_aug_dict(val_aug_dict)
-
-    logging.debug("Exit build_pipeline routine")
-    return train_aug_pipeline, val_aug_pipeline
+    if dstype == 'train':
+        train_aug_pipeline = process_aug_dict(train_aug_dict)
+        return train_aug_pipeline
+    elif dstype == 'val':
+        val_aug_pipeline = process_aug_dict(val_aug_dict)
+        return val_aug_pipeline
+    else:
+        print("Please enter a valid type(train/val)")
 
 
 def _check_augs(augs):
@@ -74,11 +79,12 @@ def process_aug_dict(pipeline_dict, meta_augs_list=['oneof', 'oneorother']):
     logging.debug("Enter process_aug_dict routine")
     if pipeline_dict is None:
         return None
-    p = pipeline_dict.get('p', 1.0)  # probability of applying augs in pipeline
     xforms = pipeline_dict['augmentations']
     composer_list = get_augs(xforms, meta_augs_list)
+    logging.debug("composer_list")
+    logging.debug(composer_list)
     logging.debug("Exit process_aug_dict routine")
-    return Compose(composer_list, p=p)
+    return Compose(composer_list)
 
 
 def get_augs(aug_dict, meta_augs_list=['oneof', 'oneorother']):
