@@ -2,7 +2,7 @@ import logging
 import numpy as np
 from scipy import ndimage as ndi
 
-from albumentations.augmentations import functional as F
+from albumentations.augmentations.geometric import functional as F
 from albumentations.core.transforms_interface import DualTransform, \
     to_tuple
 
@@ -53,7 +53,7 @@ class Rotate(DualTransform):
         self.cval = cval
 
     def apply(self, im_arr, angle=0, border_mode='reflect',
-              cval=0, rows=0, cols=0):
+              cval=0):
         """Apply rotation on image array im_arr using rotation parameters.
 
         Parameters
@@ -105,6 +105,7 @@ class Rotate(DualTransform):
         logging.debug("Enter Rotate get_params routine")
         return {'angle': np.random.randint(self.limit[0], self.limit[1])}
 
+
     def apply_to_bbox(self, bbox, angle=0, rows=0, cols=0):
         """Apply rotation to bounding box bbox using rotation parameters.
 
