@@ -47,8 +47,10 @@ class DiceSplineLoss(nn.Module):
 
     Parameters
     ----------
-    args : list
-        arguments list.
+    eps : float
+        epsilon
+    alpha : float
+        weighted average component
 
     References
     ----------
@@ -58,27 +60,15 @@ class DiceSplineLoss(nn.Module):
 
     """
 
-    def __init__(self, args):
-        """Initialise loss module.
-
-        Parameters
-        ----------
-        args : list
-            arguments list.
-
-        """
+    def __init__(self, alpha, patch_size, eps=1e-7):
         super(DiceSplineLoss, self).__init__()
-        self.gpu = args.gpu
-        self.patch_size = args.input_shape[2]
 
-        if hasattr(args, 'eps'):
-            self.eps = args.eps
-        else:
-            self.eps = 1e-7
+        self.eps = eps
+        self.alpha = alpha
+        self.patch_size = patch_size
 
-        self.dice = DiceLoss(args)
-        self.spline = SplineLoss(args)
-        self.alpha = args.dice_spline_cntrl
+        self.dice = DiceLoss(eps=self.eps)
+        self.spline = SplineLoss(patch_size=self.patch_size)
 
     def forward(self, predicted, target):
         """Compute loss between :attr:`predicted` and :attr:`target`.
