@@ -17,8 +17,8 @@ class JaccardLoss(nn.Module):
 
     Parameters
     ----------
-    args : type
-        Description of parameter `args`.
+    eps : float
+        epsilon
 
     References
     ----------
@@ -26,22 +26,9 @@ class JaccardLoss(nn.Module):
 
     """
 
-    def __init__(self, args):
-        """Initialise loss module.
-
-        Parameters
-        ----------
-        args : list
-            arguments list.
-
-        """
+    def __init__(self, eps=1e-7):
         super(JaccardLoss, self).__init__()
-        self.gpu = args.gpu
-
-        if hasattr(args, 'eps'):
-            self.eps = args.eps
-        else:
-            self.eps = 1e-7
+        self.eps = eps
 
     def forward(self, predicted, target):
         """Compute loss between :attr:`predicted` and :attr:`target`.
@@ -80,8 +67,7 @@ class JaccardLoss(nn.Module):
             target_1_hot = target_1_hot.permute(0, 3, 1, 2).float()
             # probas = F.softmax(predicted, dim=1) #apply before model output
 
-        if self.gpu > -1:
-            target_1_hot = target_1_hot.cuda(self.gpu)
+        target_1_hot = target_1_hot.to(predicted.device)
 
         target_1_hot = target_1_hot.type(predicted.type())
         dims = (0,) + tuple(range(2, target.ndimension()))
