@@ -1,14 +1,17 @@
 import numpy as np
 import math
+import logging
 
 
 def fast_hist(predicted, target, num_classes):
+    logging.debug("Inside fast_hist routine")
     k = (predicted >= 0) & (target < num_classes)
     return np.bincount(num_classes * predicted[k].astype(np.uint8) + target[k],
                        minlength=num_classes**2).reshape(num_classes, num_classes)
 
 
 def cal_kappa(hist):
+    logging.debug("Enter cal_kappa routine")
     if hist.sum() == 0:
         po = 0
         pe = 1
@@ -20,10 +23,12 @@ def cal_kappa(hist):
             kappa = 0
         else:
             kappa = (po - pe) / (1 - pe)
+    logging.debug("Exit cal_kappa routine")
     return kappa
 
 
 def mIoU_and_SeK(predicted, target, num_classes):
+    logging.debug("Enter mIoU_and_SeK routine")
     hist = fast_hist(predicted.flatten(), target.flatten(), num_classes)
     hist_fg = hist[1:, 1:]
     c2hist = np.zeros((2, 2))
@@ -39,12 +44,15 @@ def mIoU_and_SeK(predicted, target, num_classes):
     IoU_mean = (iu[0] + iu[1]) / 2
     Sek = (kappa_n0 * math.exp(IoU_fg)) / math.e
 
+    logging.debug("Exit mIoU_and_SeK routine")
     return IoU_mean, Sek
 
 
 def mIoU(predicted, target, num_classes):
+    logging.debug("Evaluating mIoU")
     return mIoU_and_SeK(predicted, target, num_classes)[0]
 
 
 def SeK(predicted, target, num_classes):
+    logging.debug("Evaluating SeK")
     return mIoU_and_SeK(predicted, target, num_classes)[1]
