@@ -1,4 +1,5 @@
 import torch
+import logging
 
 
 class EarlyStop():
@@ -14,6 +15,7 @@ class EarlyStop():
         self.early_stop = False
 
     def __call__(self, metric, model):
+        logging.debug("Enter EarlyStop __call__ routine")
         score = - metric if self.min is True else metric
 
         if self.best_score is None:
@@ -27,6 +29,9 @@ class EarlyStop():
             self.best_score = score
             self.save_checkpoint(model)
             self.counter = 0
+        logging.debug("Exit EarlyStop __call__ routine")
 
     def save_checkpoint(self, model):
+        logging.debug("Enter EarlyStop save_checkpoint routine")
         torch.save(model.state_dict(), self.checkpoint)
+        logging.debug("Exit EarlyStop save_checkpoint routine")
