@@ -41,3 +41,20 @@ def get_optimizer(key, args, model):
     args['params'] = model.parameters()
     logging.debug("Exit get_optimizer routine")
     return optimizer(**args)
+
+def set_optimizer(key, optimizer):
+    """Allows: 
+
+    1.Addition of a new optimizer to optimizer map
+    2.Modification of existing optimizer definitions in optimizer map
+
+    Parameters
+    ----------
+    key : string
+        type of optimizer instance
+    optimizer : torch.optim
+        optimizer class
+    """
+    logging.debug("Enter set_optimizer routine")
+    optimizer_map[key] = optimizer
+    logging.debug("Exit set_optimizer routine")
