@@ -41,3 +41,20 @@ def get_scheduler(key, args, optimizer):
     args['optimizer'] = optimizer
     logging.debug("Exit get_scheduler routine")
     return scheduler(**args)
+
+def set_scheduler(key, scheduler):
+    """Allows: 
+
+    1.Addition of a new scheduler to scheduler map
+    2.Modification of existing scheduler definitions in scheduler map
+
+    Parameters
+    ----------
+    key : string
+        type of scheduler instance
+    scheduler : torch.optim
+        scheduler class
+    """
+    logging.debug("Enter set_scheduler routine")
+    scheduler_map[key] = scheduler
+    logging.debug("Exit set_scheduler routine")
